// pages/index.tsx
'use client'
import React, { useEffect, useState } from 'react';
import Image from 'next/image';
import Left from '@/components/left';
import { LeftCol } from '@/components/LeftCol';
import VisaInfo from '@/app/visaInfo';
import Test from '@/components/Example/test';
import Loading from '@/components/Loading';

const Home = () => {
  const [tripType, setTripType] = useState('One way');
  const [passengerCount, setPassengerCount] = useState(1);
  const [classType, setClassType] = useState('Economy');
  const [from, setFrom] = useState('Houston (HOU)');
  const [to, setTo] = useState('');
  const [departureDate, setDepartureDate] = useState('');
  const [returnDate, setReturnDate] = useState('');

  const handleSearch = () => {
    console.log({
      tripType,
      passengerCount,
      classType,
      from,
      to,
      departureDate,
      returnDate,
    });
  };

  const [loading, setLoading] = useState(true);

  // Use useEffect to handle the loading logic
  useEffect(() => {
    // Set a timer for 2 seconds to simulate the loading phase
    const timer = setTimeout(() => {
      setLoading(false);
    }, 1800); // Set the delay to 2 seconds (2000ms)

    // Cleanup the timer when the component unmounts
    return () => clearTimeout(timer);
  }, []);

  // Render the loading animation while loading is true
  if (loading) {
    return <Loading />;
  }


  return (
      <div className="w-full h-full bg-white flex flex-col overflow-hidden">
        <header className="bg-white p-4 flex justify-between items-center border-b mx-6">
          <div className="flex items-center space-x-2">
            <span className="text-indigo-600 text-2xl">✈</span>
            <span className="text-emerald-600 font-bold text-xl">Passportme</span>
          </div>
          <div className="text-gray-400 text-sm">Home - Visa Processing</div>
          <div className="flex items-center space-x-4">
            <span className="text-gray-600 text-sm">BD</span>
            <div className="w-8 h-8 bg-indigo-100 rounded-full flex items-center justify-center">
              <span className="text-indigo-600">🌐</span>
            </div>
            <div className="w-8 h-8 bg-yellow-100 rounded-full flex items-center justify-center">
              <span className="text-yellow-600">🔔</span>
            </div>
            <Image src="/japan.jpg" alt="User" width={32} height={32} className="rounded-full" />
          </div>
        </header>

        <main className="p-6 m-4 mt-24">
          {/* <h1 className="text-3xl font-bold mb-6">Find your Destination</h1> */}

          {/* <div className="flex space-x-4 mb-6">
            <button 
              className={`px-4 py-2 rounded-full text-sm ${tripType === 'Round trip' ? 'bg-green-100 text-green-700' : 'bg-gray-200'}`}
              onClick={() => setTripType('Round trip')}
            >
              Round trip
            </button>
            <button 
              className={`px-4 py-2 rounded-full text-sm ${tripType === 'One way' ? 'bg-green-100 text-green-700' : 'bg-gray-200'}`}
              onClick={() => setTripType('One way')}
            >
              One way
            </button>
            <select
              value={passengerCount}
              onChange={(e) => setPassengerCount(parseInt(e.target.value))}
              className="px-4 py-2 bg-gray-100 rounded-full text-sm"
            >
              {[...Array(10).keys()].map(num => (
                <option key={num} value={num + 1}>{num + 1} Passenger{num > 0 && 's'}</option>
              ))}
            </select>
            <select
              value={classType}
              onChange={(e) => setClassType(e.target.value)}
              className="px-4 py-2 bg-gray-100 rounded-full text-sm"
            >
              <option value="Economy">Economy</option>
              <option value="Business">Business</option>
              <option value="First">First</option>
            </select>
          </div> */}

          {/* <div className="flex mb-6">
            <div className="flex-grow bg-emerald-600 text-white p-4 rounded-l-lg">
              <div className="text-sm opacity-80">From</div>
              <div className="font-semibold">{from}</div>
            </div>
            <div className="flex-grow bg-emerald-600 text-white p-4 flex items-center">
              <div className="mr-2">⇌</div>
              <input
                type="text"
                placeholder="Where is your destination?"
                value={to}
                onChange={(e) => setTo(e.target.value)}
                className="bg-emerald-600 text-white placeholder-white focus:outline-none"
              />
            </div>
            <button 
              className="bg-black/85 px-6 rounded-r-lg flex items-center justify-center"
              onClick={handleSearch}
            >
              <svg className="w-6 h-6 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z" />
              </svg>
            </button>
          </div> */}

          <div className="flex space-x-8">
            <div className="w-1/2">
                <LeftCol />
            </div>

            <div className="w-1/2">
              <div className="mb-4">
                <div className="text-xl font-bold text-emerald-600">France</div>
                <div className="text-sm text-gray-500">Apply for appointment now</div>
              </div>

              {/* <div className="flex items-center space-x-4 mb-6">
                <div className="w-16 h-16 bg-yellow-400 rounded-full flex items-center justify-center text-2xl font-bold text-white">
                  28°
                </div>
                <span className="text-gray-600">mostly sunny</span>
              </div> */}

              <div className="relative">
                <Image src="/map.jpg" alt="World Map" width={500} height={300} className="rounded-lg" />
                <div className="absolute top-[55%] left-1/2 transform -translate-x-1/2 -translate-y-1/2">
                  <div className="w-5 h-5 bg-indigo-400 rounded-full animate-pulse"></div>
                </div>
                <div className="absolute top-1/4 right-1/3 transform -translate-x-1/2 -translate-y-1/2">
                  <div className="w-4 h-4 bg-green-500 rounded-full animate-pulse"></div>
                </div>
              </div>
            </div>
          </div>
          
        </main>
        <div>
        <VisaInfo />
        
        </div>
      </div>
  );
};

export default Home;
